@@ -12,7 +12,7 @@ import os
 import time
 import threading
 
-print("Package to control the 3d printed raspberry pi powered evolution contraption")
+print("imported pi3dec - package to control the 3d printed raspberry pi powered evolution contraption")
 
 class Experiment:
     def __init__(self, name="NewExperiment", connect=True, device_serial="auto", fit_calibration_functions=True,
