@@ -2,7 +2,6 @@ import pandas as pd
 import os
 import numpy as np
 import matplotlib.pyplot as plt
-import warnings
 
 def exp_fit(timewindow, ODwindow):
     """
@@ -131,7 +130,7 @@ def plot_tube(pe, tube, log_OD=None, log_pumps=None, plot_growth_rate=True,windo
     plt.gca().add_artist(legend)
     ax.grid()
     #         ax4.grid()
-    plt.suptitle("Vial %d" % tube)
+    plt.suptitle("Tube  %d" % tube)
     plt.title("%s  -  %s" % (str(time0), str(time_last)), fontsize=6)
     ax.set_xlabel("Time [hours]")
     plt.savefig(os.path.join(pe.name, "plot.%d.png" % tube))
